// OggMuxDlg.h : Header-File

/*****************************************************************************
 *
 *  OggMux
 *  - Front-end for Tobias Waldvogel's OGG directshow filters -
 *
 *  This program implements a GUI for those filters to multiplex different
 *  stream types (audio, video, subtitles, chapterinformation,...) into
 *  the OGG container format.
 *
 *  This program is free software ; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation ; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY ; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program ; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 ****************************************************************************/

/*****************************************************************************
 *  History:
 *
 *  v 0.9.4: Added copyright headers to the sources (Koepi)
 *
 *  All code is (c)2002 by Dirk Knop, no further code has made it into
 *  OggMux yet.
 *
 ****************************************************************************/

#if !defined(AFX_OGGMUXDLG_H__043DB4B2_824F_4784_9EA2_E005723FC4C8__INCLUDED_)
#define AFX_OGGMUXDLG_H__043DB4B2_824F_4784_9EA2_E005723FC4C8__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "MovieInfo.h"
#include <streams.h>

/////////////////////////////////////////////////////////////////////////////
// COggMuxDlg Dialogfield

class COggMuxDlg : public CDialog
{
// construction
public:
	COggMuxDlg(CWnd* pParent = NULL);	// Standard-constructor

// Dialogfield data
	//{{AFX_DATA(COggMuxDlg)
	enum { IDD = IDD_OGGMUX_DIALOG };
	CButton	m_resetbutton;
	CButton	m_clear_chapterlist;
	CButton	m_chapter_modify;
	CButton	m_chapter_delete;
	CListBox	m_chapterlist;
	CButton	m_subtitles_modify;
	CButton	m_subtitles_delete;
	CButton	m_soundtrack_modify;
	CButton	m_soundtrack_delete;
	CProgressCtrl	m_progress;
	CEdit	m_edit_quality;
	CStatic	m_static_quality;
	CButton	m_muxbutton;
	CListBox	m_subtitleslist;
	CListBox	m_soundtracklist;
	CString	m_soundtrack1;
	CString	m_targetfile;
	CString	m_movie;
	CString	m_language1;
	CString	m_language2;
	CString	m_subtitles1;
	int		m_quality;
	int		m_soundtrack_delay;
	int		m_subtitles_delay;
	CString	m_hint1;
	CString	m_hint2;
	CString	m_static_position;
	CString	m_static_position2;
	CString	m_chaptername;
	CString	m_chaptertime;
	int		m_splitsize;
	//}}AFX_DATA

	//{{AFX_VIRTUAL(COggMuxDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV-Untersttzung
	//}}AFX_VIRTUAL

// Implementation
	bool running;
	MovieInfo m_movieinfo;
protected:
	HICON m_hIcon;
	bool automate;
	CString chapters;

	void EncodeFile(CString Filename, int Quality, CString Filtername, CString Property, CString Value, IGraphBuilder *Graph, IBaseFilter *OggMuxer);
	void RenderFile(CString Filename, CString Filtername, CString Property, CString Value, IGraphBuilder *Graph, IBaseFilter *OggMuxer);
	void InsertChapters(IBaseFilter *OggMuxer);
	void FetchFile(CString *Target, CString Filetype);
	void set_soundtrack(int number);
	void set_subtitles(int number);
	void set_chapter(int number);
	POSITION get_soundtrack_pos(int number);
	POSITION get_soundlang_pos(int number);
	POSITION get_soundqual_pos(int number);
	POSITION get_sounddelay_pos(int number);
	POSITION get_subtitles_pos(int number);
	POSITION get_subtlang_pos(int number);
	POSITION get_subtdelay_pos(int number);
	POSITION get_chaptername_pos(int number);
	POSITION get_chaptertime_pos(int number);
	void build_soundtrack_list();
	void build_subtitles_list();
	void build_chapter_list();
	void automisation(CString setupfile);

	HRESULT AddToRot(IUnknown *pUnkGraph, DWORD *pdwRegister);
	void RemoveFromRot(DWORD pdwRegister);

	CToolTipCtrl m_ToolTip;
	PreTranslateMessage(MSG *msg);

	//{{AFX_MSG(COggMuxDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnBMuxfile();
	afx_msg void OnBOpenmovie();
	afx_msg void OnBOpensoundtrack1();
	afx_msg void OnBSavetargetfile();
	afx_msg void OnBOpensubtitles1();
	afx_msg void OnSelchangeComboLanguage1();
	afx_msg void OnSelchangeComboLanguage2();
	afx_msg void OnBAddsoundtrack();
	afx_msg void OnBAddsubtitles();
	afx_msg void OnSelchangeListSoundtracks();
	afx_msg void OnSelchangeListSoundlanguages();
	afx_msg void OnSelchangeListSublanguages();
	afx_msg void OnSelchangeListSubtitles();
	afx_msg void OnUpdateESoundtrack1();
	afx_msg void OnBReset();
	afx_msg void OnBAbout();
	afx_msg void OnBSoundtrackModify();
	afx_msg void OnBSoundtrackDelete();
	afx_msg void OnBSubtitleModify();
	afx_msg void OnBSubtitleDelete();
	afx_msg void OnBAddchapter();
	afx_msg void OnBChapterDelete();
	afx_msg void OnBChapterModify();
	afx_msg void OnSelchangeListChapters();
	afx_msg void OnBImportChapters();
	afx_msg void OnBClearChapterlist();
	afx_msg void OnMovieinfo();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}

#endif // !defined(AFX_OGGMUXDLG_H__043DB4B2_824F_4784_9EA2_E005723FC4C8__INCLUDED_)
